@@ -24,8 +24,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 from smartcard.CardConnectionEvent import CardConnectionEvent
-from smartcard.Exceptions import SmartcardException
-from smartcard.Observer import Observer
 from smartcard.Observer import Observable
 
 
