@@ -22,6 +22,7 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 from smartcard.pcsc.PCSCCardRequest import PCSCCardRequest
 
 
@@ -75,9 +76,10 @@ if __name__ == '__main__':
     """Small sample illustrating the use of CardRequest.py."""
 
     from smartcard.util import toHexString
-    print 'Insert a new card within 10 seconds'
+    print('Insert a new card within 10 seconds')
     cr = CardRequest(timeout=10, newcardonly=True)
     cs = cr.waitforcard()
     cs.connection.connect()
-    print cs.connection.getReader(), toHexString(cs.connection.getATR())
+    print(cs.connection.getReader() + ' ' + toHexString(cs.connection.getATR()))
     cs.connection.disconnect()
+
