@@ -23,6 +23,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
+from __future__ import print_function
 from smartcard.CardType import AnyCardType
 from smartcard.CardRequest import CardRequest
 from smartcard.CardConnectionObserver import ConsoleCardConnectionObserver
@@ -45,13 +46,13 @@ class SecureChannelConnection(CardConnectionDecorator):
 
     def cypher(self, bytes):
         '''Cypher mock-up; you would include the secure channel logics here.'''
-        print 'cyphering', toHexString(bytes)
+        print('cyphering', toHexString(bytes))
         return bytes
 
     def uncypher(self, data):
         '''Uncypher mock-up;
         you would include the secure channel logics here.'''
-        print 'uncyphering', toHexString(data)
+        print('uncyphering', toHexString(data))
         return data
 
     def transmit(self, bytes, protocol=None):
@@ -99,7 +100,7 @@ cardservice.connection = FakeATRConnection(
 # connect to the card and perform a few transmits
 cardservice.connection.connect()
 
-print 'ATR', toHexString(cardservice.connection.getATR())
+print('ATR', toHexString(cardservice.connection.getATR()))
 
 apdu = SELECT + DF_TELECOM
 response, sw1, sw2 = cardservice.connection.transmit(apdu)
@@ -111,5 +112,5 @@ if sw1 == 0x9F:
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
