@@ -1,6 +1,8 @@
 """
 from Thinking in Python, Bruce Eckel
-http://mindview.net/Books/TIPython
+http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
+
+(c) Copyright 2008, Creative Commons Attribution-Share Alike 3.0.
 
 Simple emulation of Java's 'synchronized'
 keyword, from Peter Norvig.
@@ -14,12 +16,12 @@ def synchronized(method):
     def f(*args):
         self = args[0]
         self.mutex.acquire()
-        # print method.__name__, 'acquired'
+        # print(method.__name__, 'acquired')
         try:
-            return apply(method, args)
+            return method(*args)
         finally:
             self.mutex.release()
-            # print method.__name__, 'released'
+            # print(method.__name__, 'released')
     return f
 
 
@@ -29,10 +31,10 @@ def synchronize(klass, names=None):
     given, or all methods if names=None."""
     if type(names) == type(''):
             names = names.split()
-    for (name, val) in klass.__dict__.items():
+    for (name, val) in list(klass.__dict__.items()):
         if callable(val) and name != '__init__' and \
             (names == None or name in names):
-                # print "synchronizing", name
+                # print("synchronizing", name)
                 setattr(klass, name, synchronized(val))
 
 
