@@ -43,6 +43,18 @@ extern PyObject* PyExc_SCardError;
     #define lstrlen strlen
 #endif // PCSCLITE
 
+#if PY_MAJOR_VERSION >= 3
+
+#define PyInt_Check(x) PyLong_Check(x)
+#define PyInt_AsLong(x) PyLong_AsLong(x)
+#define PyInt_FromLong(x) PyLong_FromLong(x)
+#define PyString_Check(name) PyUnicode_Check(name)
+#define PyString_FromString(x) PyUnicode_FromString(x)
+#define PyString_AsString(str) PyBytes_AsString(str)
+
+#endif
+
+
 /**==========================================================================**/
 static int _IsAReaderState( PyObject* o)
 /*==============================================================================
@@ -91,7 +103,24 @@ static int _ReaderStateFromTuple( PyObject* o, READERSTATELIST* prl, unsigned in
 
     // first tuple item is reader name
     o2=PyTuple_GetItem(o, 0);
-    psz = PyString_AsString(o2);
+
+#if PY_MAJOR_VERSION >= 3
+    // Convert the readername from string (unicode) to bytes (ascii)
+    PyObject * temp_bytes = PyUnicode_AsEncodedString(o2, "ASCII", "strict"); // Owned reference
+    if (temp_bytes != NULL)
+    {
+        psz = PyBytes_AsString(temp_bytes); // Borrowed pointer
+        if (NULL == psz)
+            return 0;
+        psz = strdup(psz);
+        Py_DECREF(temp_bytes);
+    }
+    else
+        return 0;
+#else
+	psz = PyString_AsString(o2);
+#endif
+
     prl->aszReaderNames[x] = mem_Malloc(strlen(psz)+1);
     if (!prl->aszReaderNames[x])
     {
@@ -611,6 +640,8 @@ build a READERSTATELIST from a Python list of reader states
         mem_Free( prl );
         return NULL;
     }
+	/* zeroise SCARD_READERSTATE to work with remote desktop */
+	memset(prl->ars, 0, cRStates*sizeof(SCARD_READERSTATE) );
 
     prl->aszReaderNames = mem_Malloc( cRStates*sizeof(char*) );
     if (!prl->aszReaderNames)
@@ -1149,7 +1180,11 @@ build a Python string list from a STRINGLIST
             PyErr_SetString( PyExc_TypeError, "Expected a list of strings." );
             return NULL;
         }
+#if PY_MAJOR_VERSION >= 3
+        cChars += PyUnicode_GET_LENGTH(o) + 1 ;
+#else
         cChars += strlen( PyString_AsString(o)) + 1 ;
+#endif
     }
     cChars += 1;
 
@@ -1175,8 +1210,21 @@ build a Python string list from a STRINGLIST
         for( x=0, p=psl->ac; x<cStrings; x++ )
         {
             PyObject* o = PyList_GetItem(source, x);
+#if PY_MAJOR_VERSION >= 3
+            // Convert the group name from string (unicode) to bytes (ascii)
+            PyObject * temp_bytes = PyUnicode_AsEncodedString(o, "ASCII", "strict"); // Owned reference
+            if (temp_bytes != NULL)
+            {
+                char * psz = PyBytes_AsString(temp_bytes); // Borrowed pointer
+                if (NULL == psz)
+                    return 0;
+                strcpy(p, psz);
+                Py_DECREF(temp_bytes);
+            }
+#else
             strcpy( p, PyString_AsString(o) );
-            p += strlen( PyString_AsString(o) ) + 1;
+#endif
+            p += strlen( p ) + 1;
         }
         strcpy( p, "\0" );
     }
