@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import unittest
 from smartcard.scard import *
 
@@ -39,8 +40,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -49,13 +50,13 @@ class testcase_getATR(unittest.TestCase):
 
     def setUp(self):
         hresult, self.hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
-        self.assertEquals(hresult, 0)
+        self.assertEqual(hresult, 0)
         hresult, self.readers = SCardListReaders(self.hcontext, [])
-        self.assertEquals(hresult, 0)
+        self.assertEqual(hresult, 0)
 
     def tearDown(self):
         hresult = SCardReleaseContext(self.hcontext)
-        self.assertEquals(hresult, 0)
+        self.assertEqual(hresult, 0)
 
     def _getATR(self, r):
         if r < len(expectedATRs) and [] != expectedATRs[r]:
@@ -64,17 +65,17 @@ class testcase_getATR(unittest.TestCase):
                 self.readers[r],
                 SCARD_SHARE_SHARED,
                 SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
-            self.assertEquals(hresult, 0)
+            self.assertEqual(hresult, 0)
 
             try:
                 hresult, reader, state, protocol, atr = SCardStatus(hcard)
-                self.assertEquals(hresult, 0)
-                self.assertEquals(reader, expectedReaders[r])
-                self.assertEquals(atr, expectedATRs[r])
+                self.assertEqual(hresult, 0)
+                self.assertEqual(reader, expectedReaders[r])
+                self.assertEqual(atr, expectedATRs[r])
 
             finally:
                 hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
-                self.assertEquals(hresult, 0)
+                self.assertEqual(hresult, 0)
 
     def test_getATR0(self):
         testcase_getATR._getATR(self, 0)
